==> pointpos_api-0.0.13.tar.gz: lib/api/outlet_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/outlet.dart';

part 'outlet_api.jretro.dart';

@GenApiClient()
class OutletApi extends ApiClient with _$OutletApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    OutletApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Outlet
    ///
    /// Create Outlet
    @PostReq(path: "/outlet", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> createOutlet(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Outlet body
        ) {
        return super.createOutlet(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Outlet By ID
    ///
    /// Delete Outlet By ID
    @DeleteReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Outlet List
    ///
    /// Get Outlet  List
    @GetReq(path: "/outlet", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Outlet>> findOutlet(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findOutlet(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Outlet By ID
    ///
    /// Get Outlet By ID
    @GetReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> getOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Outlet By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> updateOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Outlet body
        ) {
        return super.updateOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/outlet_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/outlet.dart';

part 'outlet_api.jretro.dart';

@GenApiClient()
class OutletApi extends ApiClient with _$OutletApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    OutletApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Outlet
    ///
    /// Create Outlet
    @PostReq(path: "/outlet", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> createOutlet(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Outlet body
        ) {
        return super.createOutlet(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Outlet By ID
    ///
    /// Delete Outlet By ID
    @DeleteReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Outlet List
    ///
    /// Get Outlet  List
    @GetReq(path: "/outlet", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Outlet>> findOutlet(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findOutlet(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Outlet By ID
    ///
    /// Get Outlet By ID
    @GetReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> getOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Outlet By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/outlet/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Outlet> updateOutletByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Outlet body
        ) {
        return super.updateOutletByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
